function [r_k, mean_uu_polar] = calc_polar_spectrum(k1,k2,uu)
% CALC_POLAR_SPECTRUM  Calculates the 1-dimensional KE spectral density 
%                      as a function of the horizontal wavenumber by
%                      interpolation to polar coordinate and averaging
%                      along the azimuth at every radial gridpoint
% Inputs: 
%       k1: [1, n] double, wavenumber in x-direction
%       k2: [1, m] double, wavenumber in y-direction
%       uu: [m, n], double, 2-dimensional KE spectral density of U,V
% Outputs:
%       r_k: horizontal wavenumber
%       mean_uu_polar: 1-dimensional KE spectral density


% Create log-scaled r_k from k1 and k2
[K1, K2] = meshgrid(k1, k2);
dk1 = abs(k1(2)-k1(1)); dk2 = abs(k2(2)-k2(1));
min_dk1 = dk1/10; min_dk2 = dk2/10;
NR = 1+5e2; % arbitrary: get 501 values in r_k

max_r = sqrt(2)*max(max(abs(k1)), max(max(abs(k2))));
%min_r = min(min(abs(k1(k1>1e-15|k1<-1e-15))), min(abs(k2(k2>1e-15|k2<-1e-15))));
min_r = min(min(abs(k1(k1>min_dk1|k1<-min_dk1))), min(abs(k2(k2>min_dk2|k2<-min_dk2))));
r_k = logspace(log10(min_r), log10(max_r), NR); 

NTh = 1+1e3; % arbitrary: get 1001 values in theta
theta_k = linspace(0, 2*pi, NTh); 

[R_k, Theta_k] = meshgrid(r_k, theta_k); % k1 and k2 in polar coordinates

% Query points of k1, k2 in Cartesian for interpolation
K1q = R_k.*cos(Theta_k); K2q = R_k.*sin(Theta_k); 

% Interpolate uu from K1, K2 to K1q, K2q grid
uu_polar = griddata(double(K1), double(K2), double(uu), ...
                    double(K1q), double(K2q));

% Average along azimuthal dimension
mean_uu_polar = 2*pi.*r_k.*mean(uu_polar, 1);
%mean_uu_polar = trapz(theta_k,uu_polar,1)./(2*pi);

% Remove NaN entries from invalid interpolation values
r_k = r_k(~isnan(mean_uu_polar));
mean_uu_polar = mean_uu_polar(~isnan(mean_uu_polar));

return