function [r_k, corr_ctof_fine, autoCorr_ctof, autoCorr_fine] = ...
    corr_interp_orig(n, VelStruct_fine, Vel_Struct_coarse)
% CORR_INTERP_ORIG  1. Interpolates U_coarse to the grid of U_fine; 
%                   2. Computes correlation between interp2(U_coarse) and
%                      U_fine, auto-correlation of interp2(U_coarse), and 
%                      auto-correlation of U_fine.
% Inputs: 
%       n: int, the factor by which U_coarse's grid is coarser than
%          U_fine's grid
%       VelStruct_fine: 1x1 struct, U, V, X, Y of the finer velocity field
%       Vel_Struct_coarse: 1x1 struct, U, V, X, Y of the coarser velocity
%                          field
% Outputs:
%       r_k: horizontal wavenumber
%       corr_ctof_fine: Correlation between the interpolated velocity and 
%                       finer velocity
%       autoCorr_ctof: Auto-correlation of the interpolated velocity from
%                      coarse to fine grid
%       autoCorr_fine: Auto-correlation of the finer velocity field


U_fine = VelStruct_fine.U; V_fine = VelStruct_fine.V; 
X_fine = VelStruct_fine.X; Y_fine = VelStruct_fine.Y;
U_coarse = Vel_Struct_coarse.U; V_coarse = Vel_Struct_coarse.V; 
X_coarse = Vel_Struct_coarse.X; Y_coarse = Vel_Struct_coarse.Y;

[XF,YF] = meshgrid(X_fine,Y_fine); [XC,YC] = meshgrid(X_coarse,Y_coarse);

U_ctof = interp2(XC, YC, U_coarse, XF, YF, 'spline'); 
V_ctof = interp2(XC, YC, V_coarse, XF, YF, 'spline');

NX = size(U_ctof,2); NY = size(U_ctof,1); 
n2 = ceil(2*n); % ignore boundary pixels

% Crop out boundary pixels before correlation calculations
U_ctof_crop = U_ctof(n2:(NY-n2), n2:(NX-n2));
V_ctof_crop = V_ctof(n2:(NY-n2), n2:(NX-n2));
U_fine_crop = U_fine(n2:(NY-n2), n2:(NX-n2));
V_fine_crop = V_fine(n2:(NY-n2), n2:(NX-n2));

% Auto-correlation of velocity interpolated from coarse to fine
[k1_fine,k2_fine,uu_ctof] = ...
    calc_KE_fourier(X_fine(n2:(NX-n2)), Y_fine(n2:(NY-n2)),...
                    U_ctof_crop, V_ctof_crop);
[r_k, autoCorr_ctof] = calc_polar_spectrum(k1_fine,k2_fine,uu_ctof);

% Auto-correlation of finer velocity (not interpolated)
[~,~,uu_fine] = ...
    calc_KE_fourier(X_fine(n2:(NX-n2)), Y_fine(n2:(NY-n2)),...
                    U_fine_crop, V_fine_crop);
[~, autoCorr_fine] = calc_polar_spectrum(k1_fine,k2_fine,uu_fine);

% Correlation between the interpolated velocity and finer velocity
[~,~,uu_corr] = ...
    calc_Corr_fourier(X_fine(n2:(NX-n2)), Y_fine(n2:(NY-n2)),...
                      U_fine_crop, V_fine_crop, U_ctof_crop, V_ctof_crop);
[~, corr_ctof_fine] = calc_polar_spectrum(k1_fine,k2_fine,uu_corr);

return