function [Up,Vp,Us,Vs] = decomp_helmholtz(U,V,K1,K2)
% DECOMP_HELMHOLTZ  Performs Helmholtz Decomposition on the 2-D vector
%                   field U, V.
% Inputs: 
%       U: [m, n] double, u-component of velocity field
%       V: [m, n] double, v-component of velocity field
%       K1: [m, n] double, x-wavenumber of velocity field
%       K2: [m, n] double, y-wavenumber of velocity field
% Outputs:
%       Up: [m, n] double, u-component of the Potential (non-rotational)
%           velocity
%       Vp: [m, n] double, v-component of the Potential (non-rotational)
%           velocity
%       Us: [m, n] double, u-component of the Solenoidal (non-divergent)
%           velocity
%       Vs: [m, n] double, v-component of the Solenoidal (non-divergent)
%           velocity


u = fftshift(fft2(U)); v = fftshift(fft2(V)); 

Rk = sqrt(K1.^2+K2.^2);
Cosk = K1./Rk; Sink = K2./Rk;

% Remove discontinuities
Cosk(Rk==0) = 1; Sink(Rk==0) = 0;

Pk = u.*Cosk + v.*Sink; 
Sk = u.*(-Sink) + v.*Cosk;

up = Pk.*Cosk; vp = Pk.*Sink; 
us = Sk.*(-Sink); vs = Sk.*Cosk;

Up = real(ifft2(ifftshift(up))); Vp = real(ifft2(ifftshift(vp)));
Us = real(ifft2(ifftshift(us))); Vs = real(ifft2(ifftshift(vs)));

return