clc; clear; close all

data_dir = '../PIVlab_output/'; 

fcor = 2*(2*pi/3600/24)*sin(58/180*pi); % f at 58deg N

%% load data info: dates and times
Td = {'100305',   '110428',   '120524a',  '120524b',  '130519', ...
      '140423',   '140603',   '140613',   '150420',   '160426', ...
      '160503g',   '170529',   '180507',   '180530a',  '180530b', ...
      '190424',   '190526',   '200428',   '200429',   '200430', ...
      '210426'};

% Terra, time in UTC
t_hms.T = {'15:04:00', '15:33:00', '14:45:00', '14:45:00', '15:34:00', ...
           '14:27:00', '14:21:00', '14:58:00', '15:04:00', '14:39:00', ...
           '14:46:00', '14:51:00', '14:59:00', '15:05:00', '15:05:00', ...
           '14:57:00', '14:57:00', '14:45:00', '15:28:00', '16:10:00', ...
           '16:02:00'}; 

% Aqua, time in UTC
t_hms.A = {'16:54:00', '17:24:00', '16:34:00', '16:34:00', '17:23:00', ...
           '16:15:00', '16:09:00', '16:46:00', '16:51:00', '16:28:00', ...
           '16:34:00', '16:41:00', '16:47:00', '16:52:00', '16:52:00', ...
           '16:46:00', '16:47:00', '16:33:00', '17:17:00', '16:22:00', ...
           '16:16:00'};

%% vort/div histogram (Aqua-Terra/Terra-Aqua only)
Vort = []; Div = [];

% For each date in Td, list of dates when snapshots were taken
for i_day = 1:length(Td)
    td = Td{i_day}; % char array containing date of the current iteration
    disp(td)

    % time difference between Terra and Aqua in SECONDS
    dt_sec = seconds(diff(datetime([t_hms.T{i_day} ; t_hms.A{i_day}])));
    
    % Satellite name flag formatting in velocity.mat filename
    if dt_sec > 0;  satellites = 'TA'; % Aqua later than Terra
    else;   satellites = 'AT';  end % Terra later than Aqua

    % load U, V, X, Y from .mat files
    [Ud, Vd, Xd, Yd] = ...
        load_ice_uvxy([data_dir, td, '_', satellites, '.mat'], ...
                      250.0, dt_sec, '', '');

    % Gaussian filter
    Ud = imgaussfilt(Ud,2); Vd = imgaussfilt(Vd,2);

    % Discrete differentiation instead of Spectral to preserve boundary
    % pixels in sample
    [Ux, ~] = ddx2(abs(Xd(2)-Xd(1)), Ud); [Uy, ~] = ddy2(abs(Yd(2)-Yd(1)), Ud);
    [Vx, ~] = ddx2(abs(Xd(2)-Xd(1)), Vd); [Vy, ~] = ddy2(abs(Yd(2)-Yd(1)), Vd);
%     Ux = ddx2_5pt(abs(Xd(2)-Xd(1)), Ud); Uy = ddy2_5pt(abs(Yd(2)-Yd(1)), Ud);
%     Vx = ddx2_5pt(abs(Xd(2)-Xd(1)), Vd); Vy = ddy2_5pt(abs(Yd(2)-Yd(1)), Vd);


    % Append vorticity, divergence after prev. iteration
    Vort_iday = Vx-Uy; Vort = [Vort; Vort_iday(:)]; 
    Div_iday = Ux+Vy; Div = [Div; Div_iday(:)];
end

%% plot histograms of distribution
x_limits = [0,1];
edges = linspace(x_limits(1), x_limits(2), 501);

% Adjust max y-value shown in figure suitable for logscale
y_max = max([histcounts(Vort./fcor,edges),histcounts(Div./fcor,edges)]);
y_lim_max = ceil(10^(log10(y_max)-floor(log10(y_max))))*10^floor(log10(y_max));
y_limits = [1e1, y_lim_max];

figure

% Distribution of positive vorticity
hv_pos = histogram(Vort(Vort>0)./fcor,edges, ...
    'DisplayStyle','stairs', 'edgecolor', [.1 .4 .2],'linewidth', 1);
hold on

% Horizontally flipped distribution of negative vorticity
hv_neg = histogram(-Vort(Vort<0)./fcor,edges, ...
    'DisplayStyle','stairs', 'edgecolor', [.1 .4 .2]);

% Distribution of positive divergence
hd_pos = histogram(Div(Div>0)./fcor,edges, ...
    'DisplayStyle','stairs', 'edgecolor', [.8 .5 .1], 'linewidth', 1);

% Horizontally flipped distribution of negative divergence
hd_neg = histogram(-Div(Div<0)./fcor,edges, ...
    'DisplayStyle','stairs', 'edgecolor', [.8 .5 .1]);

plot([0,0],y_limits, 'color', [.75,.75,.75],'linewidth', 2) % ref. vertical 0

% Phantom lines outside of xlim & ylim for legend icon display
lv_pos = plot(0.5.*x_limits+x_limits(2), 0.5.*y_limits+y_limits(2), ...
    'color', [.1 .4 .2], 'linewidth', 1);
lv_neg = plot(0.5.*x_limits+x_limits(2), 0.5.*y_limits+y_limits(2), ...
    'color', [.1 .4 .2]);
ld_pos = plot(0.5.*x_limits+x_limits(2), 0.5.*y_limits+y_limits(2), ...
    'color', [.8 .5 .1], 'linewidth', 1);
ld_neg = plot(0.5.*x_limits+x_limits(2), 0.5.*y_limits+y_limits(2), ...
    'color', [.8 .5 .1]);

grid on
set(gca, 'yscale', 'log')
xlim(x_limits); ylim(y_limits);
ylabel('count')

legend([lv_pos, lv_neg, ld_pos, ld_neg], ...
    {'$\nabla \times \mathbf{u}_s / f$, positive', '$-\nabla \times \mathbf{u}_s / f$, negative', ...
    '$\nabla \cdot \mathbf{u}_s / f$, positive', '$-\nabla \cdot \mathbf{u}_s / f$, negative'}, ...
    'interpreter', 'latex')

title('Distribution of Vorticity and Divergence of All Velocity fields')
