function [Ud, Vd, Xd, Yd] = load_ice_uvxy(dir_fn, ice_grid_meter, dt_sec, hn, tp)
% LOAD_ICE_UVXY  Loads PIVlab output velocity fields in .mat files, with
%                options to apply tapering.
% Inputs: 
%       dir_fn: filename
%       ice_grid_meter: double, known pixel side length in METERS
%       dt_sec: double, known time separation between two snapshots in
%               SECONDS
%       hn: char array, option to apply hanning window if non-empty char
%       tp: char array, option to apply tanh tapering if non-empty char
% Outputs:
%       Ud: [m, n] double, u-component of velocity field
%       Vd: [m, n] double, v-component of velocity field
%       Xd: [1, n] double, x-coordinates of Ud, Vd
%       Yd: [m, 1] double, y-coordinates of Ud, Vd


PIV_mat = load(dir_fn);

Vd=PIV_mat.v_filtered; Ud = PIV_mat.u_filtered;

% Apply mask on velocity field, if any
TypeMask = PIV_mat.typevector_filtered; % 0 for masked, 1 for original, 
                                        % 2 for filtered
Ud(TypeMask==0) = NaN; Vd(TypeMask==0) = NaN;

% Crop to even array sizes if odd
Vd=Vd(1:2*fix(size(Vd,1)/2),1:2*fix(size(Vd,2)/2));
Ud=Ud(1:2*fix(size(Ud,1)/2),1:2*fix(size(Ud,2)/2));

% Convert from pixel displacement per snapshot to meters/second
Ud = Ud.* (ice_grid_meter) ./ dt_sec;
Vd = Vd.* (ice_grid_meter) ./ dt_sec;

% Convert x, y to meters and crop
Xd = PIV_mat.x(1,:).* ice_grid_meter;
Yd = PIV_mat.y(:,1).* ice_grid_meter;
Xd = Xd(1:size(Ud,2)); Yd = Yd(1:size(Ud,1));

% Remove mean
Ud = Ud - nanmean(nanmean(Ud)); Vd = Vd - nanmean(nanmean(Vd));

% Apply tapering if hn or tp is non-empty
[Ud,Vd] = taper_2D_UV(Xd,Yd,Ud,Vd, hn, tp);

return